@@ -1,7 +1,7 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Exception.pm
-## Version v1.3.0
-## Copyright(c) 2023 DEGUEST Pte. Ltd.
+## Version v1.3.1
+## Copyright(c) 2024 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
 ## Modified 2024/02/24
@@ -29,7 +29,7 @@ BEGIN
     $CALLER_LEVEL = 0;
     $CALLER_INTERNAL->{'Module::Generic'}++;
     $CALLER_INTERNAL->{'Module::Generic::Exception'}++;
-    our $VERSION = 'v1.3.0';
+    our $VERSION = 'v1.3.1';
 };
 
 BEGIN
@@ -129,6 +129,7 @@ sub init
     if( ref( $args->{object} ) && Scalar::Util::blessed( $args->{object} ) && $args->{object}->isa( 'Module::Generic::Exception' ) )
     {
         my $o = $args->{object};
+        $self->message( $o->message );
         $self->code( $o->code );
         $self->type( $o->type );
         $self->retry_after( $o->retry_after );
@@ -136,6 +137,7 @@ sub init
     else
     {
         # print( STDERR __PACKAGE__, "::init() Got here with args: ", Module::Generic->dump( $args ), "\n" );
+        $self->message( $args->{message} || '' );
         $self->code( $args->{code} ) if( exists( $args->{code} ) );
         $self->type( $args->{type} ) if( exists( $args->{type} ) );
         $self->retry_after( $args->{retry_after} ) if( exists( $args->{retry_after} ) );
@@ -426,7 +428,7 @@ or, re-using an exception object:
 
 =head1 VERSION
 
-    v1.3.0
+    v1.3.1
 
 =head1 DESCRIPTION
 
